@@ -15,7 +15,6 @@ class Logger(object):
         self.__checkFilePath(filename)
         self.__setupFileLog(filename)
         self.__setupConsoleLog()
-        self.__setupAlias()
 
     def __setupFileLog(self, file):
         if file is None or len(file) == 0:
@@ -35,19 +34,36 @@ class Logger(object):
         self.logger.setLevel(logging.DEBUG)
         self.logger.addHandler(console_handler)
 
-    def __setupAlias(self):
-        self.d = self.logger.debug
-        self.i = self.logger.info
-        self.w = self.logger.warning
-        self.e = self.logger.error
-        self.x = self.logger.critical
-
     def __checkFilePath(self, filename):
         arr = filename.split('/')
         if len(arr) == 1:
             return
         makeFilePath(filename)
 
+    def d(self, *args):
+        msg = ' '.join(['%s'%i for i in args])
+        self.logger.debug(msg, stacklevel=2)
+
+    def i(self, *args):
+        msg = ' '.join(['%s'%i for i in args])
+        self.logger.info(msg, stacklevel=2)
+
+    def w(self, *args):
+        msg = ' '.join(['%s'%i for i in args])
+        self.logger.warning(msg, stacklevel=2)
+
+    def e(self, *args):
+        msg = ' '.join(['%s'%i for i in args])
+        self.logger.error(msg, stacklevel=2)
+
+    def exc(self, *args):
+        msg = ' '.join(['%s'%i for i in args])
+        self.logger.exception(msg, stacklevel=3)
+
+    def x(self, *args):
+        msg = ' '.join(['%s'%i for i in args])
+        self.logger.critical(msg, stacklevel=2)
+
 
 def makeFilePath(path):
     arr = path.split('/')
@@ -63,14 +79,19 @@ def makeFilePath(path):
             os.mkdir(folder)
     return filepath
 
-
+import json
 def test():
-    log = Logger('./a/b/c/test.log')
-    log.d('debug')
-    log.i('info')
-    # log.w('warning')
-    # log.e('error')
-    # log.x('critical')
+    log = Logger()
+    log.d('debug', 1, 'a', {'k':'v'})
+    log.i('info', 'some info')
+    log.w('warning', 'some warning', json.dumps({'hello':{'key':'world'}}))
+    log.e('error', 123, 3*5)
+    try:
+        a = 1/0
+        log.d(a)
+    except:
+        log.exc('做除法的时候出错')
+    log.x('critical', -1, json.dumps([1,2,3]))
     pass
 
 
